@@ -38,9 +38,9 @@ backplane = {}
 
 def getDynamicDomain():
     f = requests.request("GET", "https://ifconfig.me")
-    ip = f.text
+    ip = f.text.replace(".", "-")
 
-    domain = f"{ip}.xip.io"
+    domain = f"{ip}.nip.io"
     return domain
 
 
@@ -131,7 +131,7 @@ def install(
 
         try:
             backplane_repo = os.getenv(
-                "BACKPLANE_REPOSITORY", "https://gitlab.com/p3r.one/backplane"
+                "BACKPLANE_REPOSITORY", "https://gitlab.com/p3r.one/backplane.git/"
             )
             clone_command = (
                 f"git clone {backplane_repo} {backplane['default_context_dir']}"
@@ -371,7 +371,7 @@ def getContainerIDs(service: str):
 @app.command()
 def start(
     services: str = typer.Option(
-        "traefik,portainer", "--service", "-s", help="Backplane Service"
+        "traefik,portainer", "--services", "-s", help="Services to start"
     ),
 ):
     backplane_services = services.split(",")
@@ -410,7 +410,7 @@ def start(
 @app.command()
 def restart(
     services: str = typer.Option(
-        "traefik,portainer", "--service", "-s", help="Backplane Service"
+        "traefik,portainer", "--services", "-s", help="Services to restart"
     ),
 ):
     backplane_services = services.split(",")
@@ -448,11 +448,9 @@ def restart(
 @app.command()
 def stop(
     services: str = typer.Option(
-        "traefik,portainer", "--service", "-s", help="Backplane Service"
-    ),
-    remove: bool = typer.Option(
-        False, "--remove", "-r", help="Remove the service including its volumes"
+        "traefik,portainer", "--services", "-s", help="Services to stop"
     ),
+    remove: bool = typer.Option(False, "--remove", "-r", help="Remove all data"),
 ):
     backplane_services = services.split(",")
 
@@ -494,7 +492,7 @@ def stop(
 @app.command()
 def status(
     services: str = typer.Option(
-        "traefik,portainer", "--service", "-s", help="Backplane Service"
+        "traefik,portainer", "--services", "-s", help="Services to get status for"
     ),
 ):
     backplane_services = services.split(",")
@@ -581,7 +579,7 @@ def status(
 @app.command()
 def logs(
     services: str = typer.Option(
-        "traefik,portainer", "--service", "-s", help="Backplane Service"
+        "traefik,portainer", "--services", "-s", help="Services to get logs for"
     )
 ):
     backplane_services = services.split(",")
@@ -634,7 +632,7 @@ def checkPrerequisites(ctx):
         sys.exit(1)
 
     if not os.path.exists(backplane["active_context_dir"]):
-        if ctx.invoked_subcommand != "install":
+        if ctx.invoked_subcommand not in ["install", "uninstall"]:
             typer.secho(
                 "config directory missing. Run 'backplane install' first.",
                 err=True,
@@ -646,8 +644,7 @@ def checkPrerequisites(ctx):
 @app.callback()
 def callback(
     ctx: typer.Context,
-    verbosity: bool = typer.Option(False, "--verbosity", "-v", help="Verbosity"),
-    debug: bool = typer.Option(False, "--debug", "-d", help="Enable Debugging"),
+    verbosity: bool = typer.Option(False, "--verbose", "-v", help="Verbose"),
     environment: str = typer.Option(
         "development", "--environment", "-e", help="Environment"
     ),
